@@ -390,7 +390,7 @@ def make_request(request_type_function, url, data, headers, json, params, **kwar
             npu_print(f"Error: {response['error']}", level="ERROR")
         elif "message" in response:
             npu_print(f"Error: {response['message']}", level="ERROR")
-    exit(1)
+    # exit(1)
 
 
 def post(url, data=None, headers=None, json=None, params=None, **kwargs):
